@@ -193,6 +193,7 @@ OC.L10N.register(
     "Select option" : "オプションを選択",
     "Personal dates" : "個人的な日程",
     "Add property of this type" : "このタイプのプロパティーを追加",
+    "Member" : "メンバー",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
@@ -228,7 +229,6 @@ OC.L10N.register(
     "Group" : "グループ",
     "Email" : "メール",
     "Contact" : "連絡先",
-    "Member" : "メンバー",
     "Moderator" : "モデレータ",
     "Admin" : "管理者",
     "Owner" : "所有者",
@@ -310,20 +310,6 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "チームでエラーが発生しました。詳細については、コンソールを確認してください。",
     "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
-    "Unable to delete contact" : "連絡先を削除できません。",
-    "Password protection" : "パスワード保護",
-    "An error happened during description sync" : "説明の同期中にエラーが発生しました",
-    "An error happened during name sync" : "名前の同期中にエラーが発生しました",
-    "Team owned by {owner}" : "{owner}が所有するチーム",
-    "Team settings" : "チーム設定",
-    "Description" : "詳細",
-    "Team resources" : "チームのリソース",
-    "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
-    "Settings" : "Settings",
-    "Actions" : "アクション",
-    "Team members" : "チームのメンバー",
-    "Add members" : "メンバーの追加",
-    "Visibility" : "公開レベル",
-    "Team membership" : "チームのメンバー"
+    "Unable to delete contact" : "連絡先を削除できません。"
 },
 "nplurals=1; plural=0;");
