@@ -9,10 +9,7 @@ OC.L10N.register(
     "Download" : "ទាញយក",
     "can edit" : "អាច​កែប្រែ",
     "Add" : "បញ្ចូល",
-    "Password protection" : "Password protection",
     "Save" : "រក្សាទុក",
-    "Description" : "ការ​អធិប្បាយ",
-    "Settings" : "Settings",
     "Cancel" : "បោះបង់",
     "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
     "Name" : "ឈ្មោះ",
