@@ -152,6 +152,7 @@ OC.L10N.register(
     "Add contact in group" : "그룹에 연락처 추가",
     "None" : "없음",
     "Select option" : "옵션 선택",
+    "Member" : "회원",
     "Unable to create the contact." : "연락처를 만들 수 없습니다.",
     "Contact not found" : "연락처를 찾을 수 없음",
     "Group {group} not found" : "그룹 {group}을(를) 찾을 수 없음",
@@ -176,7 +177,6 @@ OC.L10N.register(
     "Group" : "그룹",
     "Email" : "이메일",
     "Contact" : "연락처",
-    "Member" : "회원",
     "Moderator" : "중재자",
     "Admin" : "관리자",
     "Owner" : "소유자",
@@ -245,13 +245,6 @@ OC.L10N.register(
     "Time zone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Unable to delete contact" : "연락처를 삭제할 수 없음",
-    "Password protection" : "암호 보호",
-    "An error happened during description sync" : "설명 동기화 중 오류 발생",
-    "An error happened during name sync" : "이름 동기화 중 오류 발생",
-    "Description" : "설명",
-    "Settings" : "Settings",
-    "Add members" : "회원 추가",
-    "Visibility" : "표시 여부"
+    "Unable to delete contact" : "연락처를 삭제할 수 없음"
 },
 "nplurals=1; plural=0;");
