@@ -34,6 +34,7 @@ OC.L10N.register(
     "No results" : "Үр дүн байхгүй",
     "Pending" : "Хүлээгдэж байгаа",
     "None" : "юу ч үгүй",
+    "Member" : "Гишүүн",
     "Add member" : "Гишүүн нэмэх",
     "New contact" : "Шинэ харилцагч",
     "Close" : "Хаах",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "User" : "Хэрэглэгч",
     "Group" : "Бүлэг",
     "Email" : "Цахим шуудан",
-    "Member" : "Гишүүн",
     "Moderator" : "Шалгагч",
     "Admin" : "Админ",
     "Owner" : "Эзэмшигч",
@@ -83,9 +83,6 @@ OC.L10N.register(
     "Female" : "Эмэгтэй",
     "Male" : "Эрэгтэй",
     "Unknown" : "Үл танигдах зүйл",
-    "Time zone" : "Цагийн бүс",
-    "Password protection" : "Password protection",
-    "Description" : "Тайлбар",
-    "Settings" : "Settings"
+    "Time zone" : "Цагийн бүс"
 },
 "nplurals=2; plural=(n != 1);");
