@@ -210,6 +210,8 @@ OC.L10N.register(
     "Select option" : "選取選項",
     "Personal dates" : "個人日期",
     "Add property of this type" : "新增此類型的屬性",
+    "Member" : "成員",
+    "This is a read-only group managed by administrators. Group members can only view this group." : "此為由管理員管理的唯讀群組。群組成員僅能檢視此群組。",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
@@ -245,7 +247,6 @@ OC.L10N.register(
     "Group" : "群組",
     "Email" : "電子郵件",
     "Contact" : "聯絡人",
-    "Member" : "成員",
     "Moderator" : "主持人",
     "Admin" : "管理員",
     "Owner" : "擁有者",
@@ -329,20 +330,6 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人",
-    "Password protection" : "密碼保護",
-    "An error happened during description sync" : "描述同步時發生錯誤",
-    "An error happened during name sync" : "名稱同步時發生錯誤",
-    "Team owned by {owner}" : "{owner} 擁有的團隊",
-    "Team settings" : "團隊設定",
-    "Description" : "描述",
-    "Team resources" : "團隊資源",
-    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
-    "Settings" : "Settings",
-    "Actions" : "動作",
-    "Team members" : "團隊成員",
-    "Add members" : "新增成員",
-    "Visibility" : "能見度",
-    "Team membership" : "團隊成員資格"
+    "Unable to delete contact" : "無法刪除聯絡人"
 },
 "nplurals=1; plural=0;");
